<?php
namespace Soisy\PaymentMethod\Actions;

use Soisy\PaymentMethod\Helper\Settings;
use Soisy\PaymentMethod\Log\Logger;
use Magento\Quote\Model\Quote;

class GetSimulation
{
    public $settings;
    public $logger;

    public function __construct(
        Settings $settings,
        Logger $logger
    ) {
        $this->settings = $settings;
        $this->logger = $logger;
    }

    /**
     * Return default widget generated remotly by Soisy API
     * @param $amount
     * @param bool $zeroRate
     * @return string
     */
    public function getDefaultWidgetSimulation($amount, $zeroRate)
    {
        //return '';
        $html = '<soisy-loan-quote ' .
            'shop-id="' . $this->settings->getShopId(true) . '" ' .
            'amount="' . $amount . '" ' .
            'instalments="' . $this->settings->getPromotionalRates() . '"' .
            'zero-interest-rate="'.$zeroRate.'"></soisy-loan-quote>' .
            '<script src="https://cdn.soisy.it/loan-quote-widget.js" async defer></script>';
        return $html;
    }

    public function execute(float $amount, $quote = null)
    {
        if (!$this->settings->isActive()) {
            return false;
        }

        if ($amount < $this->settings->getMinAmount()) {
            return false;
        }

        if (!$this->settings->showSimulation()) {
            return $this->settings->getFrontendDescription();
        }

        $zeroRateWidgetSetting = false;
        if(!is_null($quote)) {
            $zeroRateWidgetSetting = $this->settings->checkZeroRate($quote->getItems(), $amount, $quote->getStoreId());
        }

        /*
         * DEFAULT WIDGET SIMULATION
         * */
        return $this->getDefaultWidgetSimulation($amount, $zeroRateWidgetSetting);

    }
}